@@ -123,7 +123,7 @@ def nal_counter(data, arities, cols, alpha=0.3):
             nal += N_ijk[i] * np.log(N_ijk[i] / N_ij[i])
     nal /= np.sum(N_ijk)
     # nal -= 0.5 * np.log(np.sum(N_ijk)) / np.sum(N_ijk) * (arities[cols[0]] - 1) * strides[0]
-    nal -= 1 / data.shape[1] * np.power(np.sum(N_ijk), -alpha) * (arities[cols[0]] - 1) * strides[0]
+    nal -= 1 / data.shape[1] * np.power(data.shape[0], -alpha) * (arities[cols[0]] - 1) * strides[0]
     return nal
 
 
