@@ -7,7 +7,7 @@ import pandas
 
 pandas.options.mode.chained_assignment = None
 from .accessory import g_test, z_test, find_causes, pairwise, dag2cpdag, independence_test, orient_v_structure, \
-    orient_propagation
+    orient_propagation, to_bnlearn
 from .score import local_score
 
 
@@ -383,7 +383,7 @@ def hc(data, method='standard', score_function='default', alpha=0.3, debug=False
                     (time_total - time_preprocess - time_checkcycle - time_score) / time_total * 100))
     else:
         raise Exception('The input method:' + method + 'is invalid.')
-    return post_process(dag, dc)
+    return  post_process(dag, dc)
 
 
 def pc_stable(data, test='default', threshold=0.05, debug=False):
